@@ -8,7 +8,7 @@ from edalize.flows.edaflow import Edaflow, FlowGraph
 
 
 class Vivado(Edaflow):
-    """The Vivado backend executes Xilinx Vivado to build systems and program the FPGA"""
+    """The Vivado flow executes AMD Vivado to create a bitstream and optionally program a board. Yosys can be used for synthesis by setting the synth option accordingly"""
 
     argtypes = ["vlogdefine", "vlogparam"]
 
@@ -19,9 +19,13 @@ class Vivado(Edaflow):
     FLOW_OPTIONS = {
         "frontends": {
             "type": "str",
-            "desc": "Tools to run before yosys (e.g. sv2v)",
+            "desc": "Tools to run before Vivado (e.g. sv2v)",
             "list": True,
         },
+        "pgm": {
+            "type": "bool",
+            "desc": "Program board after bitstream is complete",
+        },
         "pnr": {
             "type": "str",
             "desc": "Select Place & Route tool.",
@@ -63,3 +67,11 @@ class Vivado(Edaflow):
         name = self.edam["name"]
         self.commands.set_default_target(name + ".bit")
         return FlowGraph.fromdict(flow)
+
+    def run(self):
+        if self.flow_options.get("pgm"):
+
+            # Get run command from tool instance
+            vivado_inst = self.flow.get_node("vivado").inst
+            (cmd, args, cwd) = vivado_inst.run()
+            self._run_tool(cmd, args=args, cwd=cwd)
